'use strict';

const hash = require('object-hash');

class SquashedPod {

    constructor(pod){
        this._id = hash(pod.getOwnerReferences());
        this._images = pod.getImages().map(name => Object.assign({name}));
        this._labels = pod.getLabels();
        this._startTime = pod.getStartTime();
        this._relatedPods = [];
        this.addPod(pod);
    }

    addPod(pod){
        this._relatedPods.push({
            name: pod.getName(),
            status: pod.getEntityStatus()
        });
    }

    getImages(){
        return this._images;
    }

    setImageIdByName(name, id){
        const image = this._images.find(image => image.name === name);
        if(image){
            image.id = id;
        }
    }

    toJson(){
        return {
            images: this._images,
            labels: this._labels,
            startTime: this._startTime,
            relatedPods: this._relatedPods
        }
    }

}

module.exports = SquashedPod;